require "benchmark/ips"
require "cuba"
require "rack/protection"
require_relative "../lib/cuba/secure_headers"

# Cuba::SecureHeaders sets:
#
#   - X-XSS-Protection
#   - X-Frame-Options
#   - X-Content-Type-Options
#   - X-Download-Options
#   - X-Permitted-Cross-Domain-Policies
#
class CubaSecureHeaders < Cuba
  plugin(Cuba::SecureHeaders)

  define do
    on root do
      res.write("hello")
    end
  end
end

# Rack::Protection only sets:
#
#   - X-XSS-Protection
#   - X-Frame-Options
#   - X-Content-Type-Options
#
class RackProtection < Cuba
  use(Rack::Protection::FrameOptions)
  use(Rack::Protection::XSSHeader)

  define do
    on root do
      res.write("hello")
    end
  end
end

Benchmark.ips do |x|
  x.report("rack-protection") do
    RackProtection.call("PATH_INFO" => "/", "SCRIPT_NAME" => "/")
  end

  x.report("cuba-secure_headers") do
    CubaSecureHeaders.call("PATH_INFO" => "/", "SCRIPT_NAME" => "/")
  end
end

# Calculating -------------------------------------
#      rack-protection     4.938k i/100ms
#  cuba-secure_headers     6.750k i/100ms
# -------------------------------------------------
#      rack-protection     50.248k (± 7.7%) i/s -    251.838k
#  cuba-secure_headers     76.533k (± 3.5%) i/s -    384.750k
